# coding: utf-8
#
# Copyright 2023-2024 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 2024.2
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from com.sun.star.text.NotePrintMode import NotePrintModeProto  # type: ignore

class PrintSettings(ABC):
    """
    Service Class

    These properties describe the printing of the content of a text document.

    See Also:
        `API PrintSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1PrintSettings.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.PrintSettings'
    __ooo_type_name__: str = 'service'

    @property
    @abstractmethod
    def PrintAnnotationMode(self) -> NotePrintModeProto:
        """
        determines how notes are printed.
        """
        ...

    @property
    @abstractmethod
    def PrintBlackFonts(self) -> bool:
        """
        determines if characters are always printed in black.
        """
        ...

    @property
    @abstractmethod
    def PrintControls(self) -> bool:
        """
        determines if control shapes are printed.
        """
        ...

    @property
    @abstractmethod
    def PrintDrawings(self) -> bool:
        """
        determines if shapes are printed.
        """
        ...

    @property
    @abstractmethod
    def PrintEmptyPages(self) -> bool:
        """
        determines if automatically inserted empty pages are printed.
        """
        ...

    @property
    @abstractmethod
    def PrintFaxName(self) -> str:
        """
        contains the name of the fax.
        """
        ...

    @property
    @abstractmethod
    def PrintGraphics(self) -> bool:
        """
        determines if graphic objects are printed
        """
        ...

    @property
    @abstractmethod
    def PrintLeftPages(self) -> bool:
        """
        determines if left pages are printed.
        """
        ...

    @property
    @abstractmethod
    def PrintPageBackground(self) -> bool:
        """
        determines if the background color / background graphic of pages is printed.
        """
        ...

    @property
    @abstractmethod
    def PrintPaperFromSetup(self) -> bool:
        """
        specifies if the printer paper tray selection of the system printer is used.
        
        If com.sun.star.view.PrintSettings.PaperFromSetup is FALSE, then the paper tray selection of the page styles is used.
        """
        ...

    @property
    @abstractmethod
    def PrintProspect(self) -> bool:
        """
        determines if prospect printing is used.
        """
        ...

    @property
    @abstractmethod
    def PrintReversed(self) -> bool:
        """
        determines if the pages are printed in the reverse order, starting with the last page.
        """
        ...

    @property
    @abstractmethod
    def PrintRightPages(self) -> bool:
        """
        determines if right pages are printed.
        """
        ...

    @property
    @abstractmethod
    def PrintTables(self) -> bool:
        """
        determines if text tables are printed.
        """
        ...


__all__ = ['PrintSettings']